@@ -2,4 +2,4 @@ TOKEN_START_OF_TRACE = 'SOT'
 TOKEN_END_OF_TRACE = 'EOT'
 TOKEN_DEFAULT = 'Other'
 
-TOKEN_END_OF_STREAM = 'EOS'
+TOKEN_END_OF_STREAM = None
